@@ -35,7 +35,7 @@ gg_linerange <- function(data = NULL,
                          stat = "identity",
                          position = "identity",
                          coord = ggplot2::coord_cartesian(clip = "off"),
-                         mode = NULL,
+                         mode = NULL, mode_orientation = NULL,
                          x = NULL,
                          xmin = NULL,
                          xmax = NULL,
@@ -54,38 +54,38 @@ gg_linerange <- function(data = NULL,
                          text = NULL,
                          sample = NULL,
                          mapping = NULL,
-                         x_breaks = NULL,
+                         x_breaks = NULL, x_breaks_n = NULL, 
                          x_expand = NULL,
                          x_expand_limits = NULL,
-                         x_labels = NULL,
-                         x_limits = NULL,
-                         x_oob = scales::oob_keep,
-                         x_orientation = NULL, x_position = "bottom",
-                         x_label = NULL,
-                         x_transform = NULL,
-                         y_breaks = NULL,
+                         x_label = NULL, x_labels = NULL, 
+                         
+                         
+                         x_position = "bottom", 
+                         
+                         x_sec_axis = ggplot2::waiver(), x_symmetric = NULL, x_transform = NULL,
+                         y_breaks = NULL, y_breaks_n = NULL,
                          y_expand = NULL,
                          y_expand_limits = NULL,
-                         y_labels = NULL,
-                         y_limits = NULL,
-                         y_oob = scales::oob_keep,
-                         y_orientation = NULL, y_position = "left",
-                         y_label = NULL,
+                         y_label = NULL, y_labels = NULL,
+                          y_position = "left",
+                         y_sec_axis = ggplot2::waiver(),
+                         y_symmetric = NULL, 
+                         
                          y_transform = NULL,
-                         col_breaks = NULL,
+                         col_breaks = NULL, col_breaks_n = 5,
                          col_drop = FALSE,
                          col_expand_limits = NULL,
-                         col_labels = NULL,
+                         col_label = NULL, col_labels = NULL,
                          col_legend_ncol = NULL,
                          col_legend_nrow = NULL,
                          col_legend_rev = FALSE,
-                         col_limits = NULL,
-                         col_oob = scales::oob_keep,
+                         
+                         
                          col_palette = NULL,
                          col_palette_na = NULL,
                          col_rescale = scales::rescale(),
                          col_steps = FALSE,
-                         col_label = NULL,
+                         
                          col_transform = NULL,
                          facet_axes = NULL,
                          facet_axis_labels = "margins",
@@ -106,7 +106,7 @@ gg_linerange <- function(data = NULL,
     stat = stat,
     position = position,
     coord = coord,
-    mode = mode,
+    mode = mode, mode_orientation = mode_orientation,
     x = {{ x }},
     y = {{ y }},
     xmin = {{ xmin }},
@@ -129,18 +129,18 @@ gg_linerange <- function(data = NULL,
     x_expand = x_expand,
     x_expand_limits = x_expand_limits,
     x_labels = x_labels,
-    x_limits = x_limits,
-    x_oob = x_oob,
-    x_orientation = x_orientation, x_position = x_position,
+    x_breaks_n = x_breaks_n,
+    x_sec_axis = x_sec_axis,
+    x_symmetric = x_symmetric, x_position = x_position,
     x_label = x_label,
     x_transform = x_transform,
     y_breaks = y_breaks,
     y_expand = y_expand,
     y_expand_limits = y_expand_limits,
     y_labels = y_labels,
-    y_limits = y_limits,
-    y_oob = y_oob,
-    y_orientation = y_orientation, y_position = y_position,
+    y_breaks_n = y_breaks_n,
+    y_sec_axis = y_sec_axis,
+    y_symmetric = y_symmetric, y_position = y_position,
     y_label = y_label,
     y_transform = y_transform,
     col_breaks = col_breaks,
@@ -150,8 +150,8 @@ gg_linerange <- function(data = NULL,
     col_legend_ncol = col_legend_ncol,
     col_legend_nrow = col_legend_nrow,
     col_legend_rev = col_legend_rev,
-    col_limits = col_limits,
-    col_oob = col_oob,
+    col_breaks_n = col_breaks_n,
+    
     col_palette = col_palette,
     col_palette_na = col_palette_na,
     col_rescale = col_rescale,
